@@ -7,7 +7,8 @@ import java.io.Serializable;
 import java.util.ArrayList;
 
 /**
- * @author Federico De Faveri defaveri@isti.cnr.it
+ * 
+ * @author Giancarlo Panichi
  *
  */
 public class AvailableCharsetList implements Serializable {
@@ -21,27 +22,16 @@ public class AvailableCharsetList implements Serializable {
 		super();
 	}
 
-	/**
-	 * @param charsetList
-	 * @param defaultCharset
-	 */
-	public AvailableCharsetList(ArrayList<String> charsetList,
-			String defaultCharset) {
+	public AvailableCharsetList(ArrayList<String> charsetList, String defaultCharset) {
 		super();
 		this.charsetList = charsetList;
 		this.defaultCharset = defaultCharset;
 	}
 
-	/**
-	 * @return the charsetList
-	 */
 	public ArrayList<String> getCharsetList() {
 		return charsetList;
 	}
 
-	/**
-	 * @return the defaultCharset
-	 */
 	public String getDefaultCharset() {
 		return defaultCharset;
 	}
